@@ -1,9 +1,8 @@
 #!/usr/bin/env python3
 
 import math
-from typing import Tuple
 
-def DD_to_DMS(latlon_DD: Tuple[float], return_as_str=False):
+def DD_to_DMS(latlon_DD: tuple[float, float], return_as_str=False):
     """
     Assumes positive N/S values for northern hemisphere and negative values for southern hemisphere.
     Similarly, positive values for eastern hemisphere, negative values for western hemisphere.
