@@ -3,7 +3,8 @@
 import cv2
 import logging
 from pathlib import Path
-from comfun import utils
+
+import comfun.file_ops
 
 
 def cvt_imgs(fdir_root, input_exts: tuple = (".webp",), out_ext=".jpg", recursive=True) -> None:
@@ -15,7 +16,7 @@ def cvt_imgs(fdir_root, input_exts: tuple = (".webp",), out_ext=".jpg", recursiv
     :param recursive:
     :return:
     """
-    fpaths_webp = utils.get_all_fpaths_by_extension(fdir_root, exts=input_exts, recursive=recursive)
+    fpaths_webp = comfun.file_ops.get_all_fpaths_by_extension(fdir_root, exts=input_exts, recursive=recursive)
     for fpath in fpaths_webp:
         new_path = str(Path(fpath).parent / (Path(fpath).stem + out_ext))
         try:
@@ -28,4 +29,5 @@ def cvt_imgs(fdir_root, input_exts: tuple = (".webp",), out_ext=".jpg", recursiv
 
 if __name__ == "__main__":
     fpath = "/media/findux/DATA/Wallpaper/"
+    # fpath = "/media/findux/DATA/Pictures/midjourney/egyptian_cyberpunk/"
     cvt_imgs(fdir_root=fpath, input_exts=(".webp", ".avif"))
